@@ -8,8 +8,8 @@
 #ifndef KCDDB_GENRES_H
 #define KCDDB_GENRES_H
 
+#include <kcddb_export.h>
 #include <QtCore/QStringList>
-#include <libkcddb/kcddb_export.h>
 
 namespace KCDDB
 {
