@@ -17,15 +17,10 @@
   Boston, MA 02110-1301, USA.
 */
 
-
 #include "musicbrainzlookup.h"
 
-#include <kdebug.h>
-#include <kcodecs.h>
-#include <klocale.h>
-#include <qcryptographichash.h>
-#include <cstdio>
-#include <cstring>
+#include "kcddbi18n.h"
+
 #include <musicbrainz5/Query.h>
 #include <musicbrainz5/Medium.h>
 #include <musicbrainz5/Release.h>
@@ -39,6 +34,14 @@
 #include <musicbrainz5/NameCredit.h>
 #include <musicbrainz5/SecondaryType.h>
 
+#include <KCodecs/KCodecs>
+
+#include <QtCore/QCryptographicHash>
+#include <QtCore/QDebug>
+
+#include <cstdio>
+#include <cstring>
+
 namespace KCDDB
 {
   MusicBrainzLookup::MusicBrainzLookup()
@@ -55,19 +58,19 @@ namespace KCDDB
   {
     QString discId = calculateDiscId(trackOffsetList);
 
-    kDebug() << "Should lookup " << discId;
+    qDebug() << "Should lookup " << discId;
 
     MusicBrainz5::CQuery Query("libkcddb-0.5");
 
     // Code adapted from libmusicbrainz/examples/cdlookup.cc
 
     try {
-      MusicBrainz5::CMetadata Metadata=Query.Query("discid",discId.toAscii().constData());
+      MusicBrainz5::CMetadata Metadata=Query.Query("discid",discId.toLatin1().constData());
 
       if (Metadata.Disc() && Metadata.Disc()->ReleaseList())
       {
         MusicBrainz5::CReleaseList *ReleaseList=Metadata.Disc()->ReleaseList();
-        kDebug() << "Found " << ReleaseList->NumItems() << " release(s)";
+        qDebug() << "Found " << ReleaseList->NumItems() << " release(s)";
 
         int relnr=1;
 
@@ -90,22 +93,22 @@ namespace KCDDB
             //However, these releases will include information for all media in the release
             //So we need to filter out the only the media we want.
 
-            MusicBrainz5::CMediumList MediaList=FullRelease->MediaMatchingDiscID(discId.toAscii().constData());
+            MusicBrainz5::CMediumList MediaList=FullRelease->MediaMatchingDiscID(discId.toLatin1().constData());
 
             if (MediaList.NumItems() > 0)
             {
               /*if (FullRelease->ReleaseGroup())
-                kDebug() << "Release group title: " << FullRelease->ReleaseGroup()->Title();
+                qDebug() << "Release group title: " << FullRelease->ReleaseGroup()->Title();
               else
-                kDebug() << "No release group for this release";*/
+                qDebug() << "No release group for this release";*/
 
-              kDebug() << "Found " << MediaList.NumItems() << " media item(s)";
+              qDebug() << "Found " << MediaList.NumItems() << " media item(s)";
 
               for (int i=0; i < MediaList.NumItems(); i++)
               {
                 MusicBrainz5::CMedium* Medium= MediaList.Item(i);
 
-                /*kDebug() << "Found media: '" << Medium.Title() << "', position " << Medium.Position();*/
+                /*qDebug() << "Found media: '" << Medium.Title() << "', position " << Medium.Position();*/
 
                 CDInfo info;
                 info.set(QLatin1String( "source" ), QLatin1String( "musicbrainz" ));
@@ -115,7 +118,7 @@ namespace KCDDB
                 if (relnr == 1)
                   info.set(QLatin1String( "discid" ), discId);
                 else
-                  info.set(QLatin1String( "discid" ), discId+QLatin1String( "-" )+QString::number(relnr));
+                  info.set(QLatin1String( "discid" ), QVariant(discId+QLatin1String( "-" )+QString::number(relnr)));
 
                 QString title = QString::fromUtf8(FullRelease->Title().c_str());
 
@@ -126,7 +129,7 @@ namespace KCDDB
                 info.set(Artist, artistFromCreditList(FullRelease->ArtistCredit()));
 
                 QString date = QString::fromUtf8(FullRelease->Date().c_str());
-                QRegExp yearRe("^(\\d{4,4})(-\\d{1,2}-\\d{1,2})?$");
+                QRegExp yearRe(QString::fromUtf8("^(\\d{4,4})(-\\d{1,2}-\\d{1,2})?$"));
                 int year = 0;
                 if (yearRe.indexIn(date) > -1)
                 {
@@ -176,71 +179,71 @@ namespace KCDDB
 
     catch (MusicBrainz5::CConnectionError& Error)
     {
-      kDebug() << "Connection Exception: '" << Error.what() << "'";
-      kDebug() << "LastResult: " << Query.LastResult();
-      kDebug() << "LastHTTPCode: " << Query.LastHTTPCode();
-      kDebug() << "LastErrorMessage: " << QString::fromUtf8(Query.LastErrorMessage().c_str());
+      qDebug() << "Connection Exception: '" << Error.what() << "'";
+      qDebug() << "LastResult: " << Query.LastResult();
+      qDebug() << "LastHTTPCode: " << Query.LastHTTPCode();
+      qDebug() << "LastErrorMessage: " << QString::fromUtf8(Query.LastErrorMessage().c_str());
 
       return ServerError;
     }
 
     catch (MusicBrainz5::CTimeoutError& Error)
     {
-      kDebug() << "Timeout Exception: '" << Error.what() << "'";
-      kDebug() << "LastResult: " << Query.LastResult();
-      kDebug() << "LastHTTPCode: " << Query.LastHTTPCode();
-      kDebug() << "LastErrorMessage: " << QString::fromUtf8(Query.LastErrorMessage().c_str());
+      qDebug() << "Timeout Exception: '" << Error.what() << "'";
+      qDebug() << "LastResult: " << Query.LastResult();
+      qDebug() << "LastHTTPCode: " << Query.LastHTTPCode();
+      qDebug() << "LastErrorMessage: " << QString::fromUtf8(Query.LastErrorMessage().c_str());
 
       return ServerError;
     }
 
     catch (MusicBrainz5::CAuthenticationError& Error)
     {
-      kDebug() << "Authentication Exception: '" << Error.what() << "'";
-      kDebug() << "LastResult: " << Query.LastResult();
-      kDebug() << "LastHTTPCode: " << Query.LastHTTPCode();
-      kDebug() << "LastErrorMessage: " << QString::fromUtf8(Query.LastErrorMessage().c_str());
+      qDebug() << "Authentication Exception: '" << Error.what() << "'";
+      qDebug() << "LastResult: " << Query.LastResult();
+      qDebug() << "LastHTTPCode: " << Query.LastHTTPCode();
+      qDebug() << "LastErrorMessage: " << QString::fromUtf8(Query.LastErrorMessage().c_str());
 
       return ServerError;
     }
 
     catch (MusicBrainz5::CFetchError& Error)
     {
-      kDebug() << "Fetch Exception: '" << Error.what() << "'";
-      kDebug() << "LastResult: " << Query.LastResult();
-      kDebug() << "LastHTTPCode: " << Query.LastHTTPCode();
-      kDebug() << "LastErrorMessage: " << QString::fromUtf8(Query.LastErrorMessage().c_str());
+      qDebug() << "Fetch Exception: '" << Error.what() << "'";
+      qDebug() << "LastResult: " << Query.LastResult();
+      qDebug() << "LastHTTPCode: " << Query.LastHTTPCode();
+      qDebug() << "LastErrorMessage: " << QString::fromUtf8(Query.LastErrorMessage().c_str());
 
       return ServerError;
     }
 
     catch (MusicBrainz5::CRequestError& Error)
     {
-      kDebug() << "Request Exception: '" << Error.what() << "'";
-      kDebug() << "LastResult: " << Query.LastResult();
-      kDebug() << "LastHTTPCode: " << Query.LastHTTPCode();
-      kDebug() << "LastErrorMessage: " << QString::fromUtf8(Query.LastErrorMessage().c_str());
+      qDebug() << "Request Exception: '" << Error.what() << "'";
+      qDebug() << "LastResult: " << Query.LastResult();
+      qDebug() << "LastHTTPCode: " << Query.LastHTTPCode();
+      qDebug() << "LastErrorMessage: " << QString::fromUtf8(Query.LastErrorMessage().c_str());
 
       return ServerError;
     }
 
     catch (MusicBrainz5::CResourceNotFoundError& Error)
     {
-      kDebug() << "ResourceNotFound Exception: '" << Error.what() << "'";
-      kDebug() << "LastResult: " << Query.LastResult();
-      kDebug() << "LastHTTPCode: " << Query.LastHTTPCode();
-      kDebug() << "LastErrorMessage: " << QString::fromUtf8(Query.LastErrorMessage().c_str());
+      qDebug() << "ResourceNotFound Exception: '" << Error.what() << "'";
+      qDebug() << "LastResult: " << Query.LastResult();
+      qDebug() << "LastHTTPCode: " << Query.LastHTTPCode();
+      qDebug() << "LastErrorMessage: " << QString::fromUtf8(Query.LastErrorMessage().c_str());
 
       return ServerError;
     }
 
     if (cdInfoList_.isEmpty())
     {
-        kDebug() << "No record found";
+        qDebug() << "No record found";
         return NoRecordFound;
     }
 
-    kDebug() << "Query succeeded :-)";
+    qDebug() << "Query succeeded :-)";
 
     return Success;
   }
@@ -302,7 +305,7 @@ namespace KCDDB
       dir.setNameFilters(QStringList(discid+QLatin1String( "*" )));
 
       QStringList files = dir.entryList();
-      kDebug() << "Cache files found: " << files.count();
+      qDebug() << "Cache files found: " << files.count();
       for (QStringList::iterator it = files.begin(); it != files.end(); ++it)
       {
         QFile f( dir.filePath(*it) );
@@ -320,7 +323,7 @@ namespace KCDDB
           infoList.append( info );
         }
         else
-          kDebug() << "Could not read file: " << f.fileName();
+          qDebug() << "Could not read file: " << f.fileName();
       }
     }
 
@@ -329,7 +332,7 @@ namespace KCDDB
 
   QString MusicBrainzLookup::artistFromCreditList(MusicBrainz5::CArtistCredit * artistCredit )
   {
-    kDebug() << k_funcinfo;
+	qDebug()/* << k_funcinfo*/;
     QString artistName;
 
     MusicBrainz5::CNameCreditList *ArtistList=artistCredit->NameCreditList();
@@ -349,7 +352,7 @@ namespace KCDDB
         artistName += QString::fromUtf8(Name->JoinPhrase().c_str());
       }
 
-      kDebug() << "Artist:" << artistName;
+      qDebug() << "Artist:" << artistName;
 
     }
 
@@ -358,5 +361,3 @@ namespace KCDDB
 }
 
 // vim:tabstop=2:shiftwidth=2:expandtab:cinoptions=(s,U1,m1
-
-#include "musicbrainzlookup.moc"
